Install and Uninstall BuildingsPy — BuildingsPy documentation

# Install and Uninstall BuildingsPy

To install the BuildingsPy module, install pip and run from a console

    python3 -m pip install --user buildingspy

To uninstall, run

    python3 -m pip uninstall buildingspy

To install the latest development version, run

    python3 -m pip install --user buildingspy@git+https://github.com/lbl-srg/buildingspy.git@master

To clone BuildingsPy for development, run

    git clone git@github.com:lbl-srg/BuildingsPy.git
    cd BuildingsPy
    python3 -m pip install --user -r requirements.txt